@@ -14,10 +14,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #if !defined (EXO_INSIDE_EXO_H) && !defined (EXO_COMPILATION)
@@ -125,6 +125,16 @@ typedef enum
   EXO_ICON_VIEW_LAYOUT_COLS
 } ExoIconViewLayoutMode;
 
+/**
+ * ExoIconView:
+ *
+ * #ExoIconView provides an alternative view on a list model.
+ * It displays the model as a grid of icons with labels. Like
+ * #GtkTreeView, it allows to select one or multiple items
+ * (depending on the selection mode, see exo_icon_view_set_selection_mode()).
+ * In addition to selection with the arrow keys, #ExoIconView supports
+ * rubberband selection, which is controlled by dragging the pointer.
+ **/
 struct _ExoIconView
 {
   GtkContainer        __parent__;
@@ -233,7 +243,7 @@ void                  exo_icon_view_icon_to_widget_coords     (const ExoIconView
                                                                gint                      ix,
                                                                gint                      iy,
                                                                gint                     *wx,
-                                                             gint                     *wy);
+                                                               gint                     *wy);
 
 GtkTreePath          *exo_icon_view_get_path_at_pos           (const ExoIconView        *icon_view,
                                                                gint                      x,
@@ -260,9 +270,15 @@ gboolean              exo_icon_view_path_is_selected          (const ExoIconView
 GList                *exo_icon_view_get_selected_items        (const ExoIconView        *icon_view);
 void                  exo_icon_view_select_all                (ExoIconView              *icon_view);
 void                  exo_icon_view_unselect_all              (ExoIconView              *icon_view);
+void                  exo_icon_view_selection_invert          (ExoIconView              *icon_view);
 void                  exo_icon_view_item_activated            (ExoIconView              *icon_view,
                                                                GtkTreePath              *path);
 
+gint                  exo_icon_view_get_item_column           (ExoIconView              *icon_view,
+                                                               GtkTreePath              *path);
+gint                  exo_icon_view_get_item_row              (ExoIconView              *icon_view,
+                                                               GtkTreePath              *path);
+
 gboolean              exo_icon_view_get_cursor                (const ExoIconView        *icon_view,
                                                                GtkTreePath             **path,
                                                                GtkCellRenderer         **cell);
@@ -306,8 +322,13 @@ gboolean              exo_icon_view_get_dest_item_at_pos      (ExoIconView
                                                                gint                      drag_y,
                                                                GtkTreePath             **path,
                                                                ExoIconViewDropPosition  *pos);
+#if GTK_CHECK_VERSION (3, 0, 0)
+cairo_surface_t      *exo_icon_view_create_drag_icon          (ExoIconView              *icon_view,
+                                                               GtkTreePath              *path);
+#else
 GdkPixmap            *exo_icon_view_create_drag_icon          (ExoIconView              *icon_view,
                                                                GtkTreePath              *path);
+#endif
 
 
 /* Interactive search support */
